@@ -21,15 +21,19 @@
 #ifndef __PY_DATABASE_H_
 #define __PY_DATABASE_H_
 
-#include <sqlite3.h>
 #include <boost/shared_ptr.hpp>
+#include <boost/scoped_ptr.hpp>
 #include "String.h"
 #include "Types.h"
-#include "PinyinArray.h"
 #include "PhraseArray.h"
 
+typedef struct sqlite3 sqlite3;
+
 namespace PY {
 
+class PinyinArray;
+struct Phrase;
+
 class SQLStmt;
 typedef boost::shared_ptr<SQLStmt> SQLStmtPtr;
 
@@ -51,12 +55,12 @@ private:
     guint m_option;
     SQLStmtPtr m_stmt;
 };
-typedef boost::shared_ptr<Query> QueryPtr;
 
 class Database {
-private:
-    Database ();
+public:
     ~Database ();
+protected:
+    Database ();
 
 public:
     SQLStmtPtr query (const PinyinArray   & pinyin,
@@ -70,11 +74,12 @@ public:
     void conditionsDouble (void);
     void conditionsTriple (void);
 
-    static Database & instance (void) {return m_instance; }
+    static void init (void);
+    static Database & instance (void) { return *m_instance; }
 
 private:
-    gboolean init (void);
-    gboolean initUserDatabase (const gchar *userdb);
+    gboolean open (void);
+    gboolean openUserDB (const gchar *userdb);
     void prefetch (void);
     void phraseSql (const Phrase & p, String & sql);
     void phraseWhereSql (const Phrase & p, String & sql);
@@ -87,7 +92,7 @@ private:
     String m_buffer;     /* temp buffer */
 
 private:
-    static Database m_instance;
+    static boost::scoped_ptr<Database> m_instance;
 };
 
 
