@@ -19,9 +19,11 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include "DoublePinyinEditor.h"
+#include "Config.h"
 
 namespace PY {
 
+#define DEFINE_DOUBLE_PINYIN_TABLES
 #include "DoublePinyinTable.h"
 
 /*
@@ -327,7 +329,7 @@ DoublePinyinEditor::isPinyin (gint i)
         return NULL;
     }
 
-    gint sheng = ID_TO_SHENG (i);
+    gint8 sheng = ID_TO_SHENG (i);
 
     if (sheng == PINYIN_ID_VOID) {
         return NULL;
@@ -340,8 +342,8 @@ inline const Pinyin *
 DoublePinyinEditor::isPinyin (gint i, gint j)
 {
     const Pinyin *pinyin;
-    gint sheng = ID_TO_SHENG (i);
-    const gint *yun = ID_TO_YUNS (j);
+    gint8 sheng = ID_TO_SHENG (i);
+    const gint8 *yun = ID_TO_YUNS (j);
 
     if (sheng == PINYIN_ID_VOID || yun[0] == PINYIN_ID_VOID)
         return NULL;
@@ -473,7 +475,7 @@ DoublePinyinEditor::processKeyEvent (guint keyval, guint keycode, guint modifier
 {
     /* handle ';' key */
     if (G_UNLIKELY (keyval == IBUS_semicolon)) {
-        if (CMSHM_FILTER (modifiers) == 0) {
+        if (cmshm_filter (modifiers) == 0) {
             if (insert (keyval))
                 return TRUE;
         }
