@@ -19,6 +19,9 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 #include "PhraseEditor.h"
+#include "Config.h"
+#include "Database.h"
+#include "PinyinProperties.h"
 #include "SimpTradConverter.h"
 
 namespace PY {
@@ -64,6 +67,13 @@ PhraseEditor::resetCandidate (guint i)
     return TRUE;
 }
 
+void
+PhraseEditor::commit (void)
+{
+    Database::instance ().commit (m_selected_phrases);
+    reset ();
+}
+
 gboolean
 PhraseEditor::selectCandidate (guint i)
 {
@@ -144,6 +154,23 @@ PhraseEditor::updateTheFirstCandidate (void)
     }
 }
 
+gboolean
+PhraseEditor::fillCandidates (void)
+{
+    if (G_UNLIKELY (m_query.get () == NULL)) {
+        return FALSE;
+    }
+
+    gint ret = m_query->fill (m_candidates, FILL_GRAN);
+
+    if (G_UNLIKELY (ret < FILL_GRAN)) {
+        /* got all candidates from query */
+        m_query.reset ();
+    }
+
+    return ret > 0 ? TRUE : FALSE;
+}
+
 };
 
 
